@@ -1,10 +1,10 @@
-__version__ = "0.2.6"
+__version__ = "0.2.7"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
-__git_branch__ = '(detached from v0.2.6)'
+__git_branch__ = '(detached from v0.2.7)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = '7433df34271ac40c27486705be2e90e117a2ebd9'
-__git_head_subject__ = 'buildout.cfg: changed isolated python version to v2.7.6.6'
+__git_head_hash__ = '2d81b0b2e7240cd0ce39bc4b07dc3ee91b7327a9'
+__git_head_subject__ = 'update homepage'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
